@@ -28,7 +28,7 @@
 
 extern void send_row_description(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend,
 							short num_fields, char **field_names);
-extern void send_complete_and_ready(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend, const int num_rows);
+extern void send_complete_and_ready(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend, const char* message, const int num_rows);
 extern POOL_REPORT_CONFIG* get_config(int *nrows);
 extern POOL_REPORT_POOLS* get_pools(int *nrows);
 extern POOL_REPORT_PROCESSES* get_processes(int *nrows);
@@ -41,4 +41,7 @@ extern void nodes_reporting(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 extern void version_reporting(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend);
 extern void cache_reporting(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend);
 
+extern void send_config_var_detail_row(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend, const char* name, const char* value, const char* description);
+extern void send_config_var_value_only_row(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend, const char* value);
+extern char* get_backend_status_string(BACKEND_STATUS status);
 #endif
